import bole from 'bole';
import { CollapsifyError } from '../collapsify.js';
const logger = bole('collapsify:fetch');
export function fetchWrapper(fetch) {
    return async (url) => {
        try {
            const response = await fetch(url);
            if (response.getStatusCode() >= 300) {
                throw new CollapsifyError(`Fetch failed, ${url} returned ${response.getStatusCode()}`);
            }
            return new ResponseWrapper(url, response);
        }
        catch (error) {
            if (error instanceof CollapsifyError) {
                throw error;
            }
            logger.error(error);
            throw new CollapsifyError(`Fetch failed, ${url} unknown error occured`);
        }
    };
}
class ResponseWrapper {
    constructor(url, response) {
        this.url = url;
        this.response = response;
    }
    getStatusCode() {
        return this.response.getStatusCode();
    }
    getContentType() {
        return this.response.getContentType();
    }
    async getAsString() {
        try {
            return await this.response.getAsString();
        }
        catch (error) {
            logger.error(error);
            throw new CollapsifyError(`Couldn't read ${this.url} as string`);
        }
    }
    async getAsArray() {
        try {
            return await this.response.getAsArray();
        }
        catch (error) {
            logger.error(error);
            throw new CollapsifyError(`Couldn't read ${this.url} as binary`);
        }
    }
}
