import { Buffer } from 'node:buffer';
import bole from 'bole';
import VERSION from '../version.js';
const logger = bole('collapsify:http');
const userAgent = `Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10; rv:60.0) Gecko/20100101 Firefox/60.0 Collapsify/${VERSION}`;
class FetchResponse {
    constructor(statusCode, contentType, blob) {
        this.statusCode = statusCode;
        this.contentType = contentType;
        this.blob = blob;
    }
    getStatusCode() {
        return this.statusCode;
    }
    getContentType() {
        return this.contentType;
    }
    async getAsString() {
        return this.blob.text();
    }
    async getAsArray() {
        return Buffer.from(await this.blob.arrayBuffer());
    }
}
export default function makeClient(defaultHeaders) {
    const cache = new Map();
    async function nodeFetch(url) {
        logger.debug('Fetching %s.', url);
        const resp = await fetch(url, {
            headers: {
                'user-agent': userAgent,
                ...defaultHeaders,
            },
        });
        return new FetchResponse(resp.status, resp.headers.get('content-type') ?? '', await resp.blob());
    }
    return nodeFetch;
}
